@@ -20,7 +20,7 @@ class MerchantCenterServiceDownException(Exception):
 def get_mct_service(adscale_key: str, cache_discovery=True):
     credentials = ServiceAccountCredentials.from_json_keyfile_name(
         adscale_key, scopes=['https://www.googleapis.com/auth/content'])
-    service = discovery.build('content', 'v2', credentials=credentials, cache_discovery=cache_discovery)
+    service = discovery.build('content', 'v2.1', credentials=credentials, cache_discovery=cache_discovery)
     return service
 
 
